@@ -2,9 +2,9 @@
 
 """
 import os
+from datetime import  timedelta
 
 import requests
-from notecoin.huobi.history.const import *
 
 
 def http_download(url: str, just_show=False) -> tuple:
