@@ -3,6 +3,7 @@ import hmac
 import json
 import logging
 import time
+from threading import Thread
 from typing import List
 
 from notecoin.okex.websocket.handle import BaseHandle
@@ -11,10 +12,12 @@ from notetool.secret import read_secret
 
 from websocket import WebSocket, WebSocketException, create_connection
 
+ping_interval = 30
+
 
 class BaseConnect:
-    def __init__(self, url, channels, channel_listen=None, api_key=None, secret_key=None, passphrase=None,
-                 private=False):
+    def __init__(self, url, channels, api_key=None, secret_key=None, passphrase=None, prefix='websocket',
+                 private=False, *args, **kwargs):
         self.url = url
         self.channels = channels
         self.api_key = api_key or read_secret(cate1='coin', cate2='okex', cate3='api_key')
@@ -23,33 +26,35 @@ class BaseConnect:
         self.private = private
         self.ws: WebSocket = create_connection(self.url)
         self.handles: List[BaseHandle] = []
-        self.channel_listen = channel_listen
+        super(BaseConnect, self).__init__(prefix=prefix, *args, **kwargs)
 
     def add_handle(self, handle: BaseHandle):
         self.handles.append(handle)
 
     def run(self):
         self.subscribe_start()
-        while True:
-            if self.channel_listen is not None:
-                new_channels = self.channel_listen()
-                old_channels_str = [str(channel) for channel in self.channels]
-                new_channels_str = [str(channel) for channel in new_channels]
-                if new_channels_str is not None and len(new_channels_str) > 0:
-                    if len(list(set(old_channels_str) - set(new_channels_str))) == len(
-                            list(set(new_channels_str) - set(old_channels_str))) == 0:
-                        self.channels = new_channels
-                        self.subscribe_restart()
-            try:
-                res = self.ws.recv()
-            except (TimeoutError, WebSocketException):
+
+        def start_heartbeat():
+            time.sleep(ping_interval)
+            self.ping()
+
+        Thread(target=start_heartbeat).start()
+
+        def on_message():
+            while True:
                 try:
-                    self.ping()
-                except Exception as e:
-                    logging.warning(f"连接关闭，正在重连:{e}")
-                    self.subscribe_restart()
-                continue
-            self.handle_data(res)
+                    res = self.ws.recv()
+                    self.handle_data(res)
+                except (TimeoutError, WebSocketException):
+                    try:
+                        self.ping()
+                    except Exception as e:
+                        logging.warning(f"连接关闭，正在重连:{e}")
+                        self.subscribe_restart()
+                    continue
+
+        Thread(target=on_message).start()
+        time.sleep(5)
 
     def handle_data(self, res):
         for handle in self.handles:
